<template>
  <div class="app-container">
    <div style="display: flex;justify-content: space-between">
      <el-form :inline="true" style="display: flex;align-items: center;flex-wrap: wrap;" >
        <el-form-item>
          <el-button
              type="primary"
              plain
              icon="Plus"
              @click="openDialog('add','',1)"
          >新增</el-button>
        </el-form-item>
        <el-form-item label="企业名称:" v-if="data.isAdmin" >
          <el-select
              v-model="data.queryParams.companyName"
              filterable
              remote
              @change="selectValue"
              reserve-keyword
              remote-show-suffix
              :remote-method="getCompanyList"
              :loading="loadingCompany"
              style="width: 240px"
          >
            <el-option
                v-for="item in data.companyList"
                :key="item.id"
                :label="item.name"
                :value="item.name"
            />
          </el-select>
        </el-form-item>
        <el-form-item v-if="data.isAdmin">
          <el-button
              type="primary"
              @click="openCopeDialog"
          >复制目录</el-button>
        </el-form-item>

      </el-form>
    </div>
    <!-- 表格数据 -->
    <el-table v-loading="loading"
              :data="dataList"
              :border="true"
              row-key="id"
              :default-expand-all="true"
              :tree-props="{ children: 'children'}"
    >
      <el-table-column label="目录名称" prop="mess"  >
        <template #default="scope">
          {{scope.row.number}} {{scope.row.mess}}
        </template>
      </el-table-column>
      <el-table-column label="排序" prop="sort"  >
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" >
        <template #default="scope">
          <el-button link type="primary" @click="openDialog('add',scope.row,2)">新增</el-button>
          <el-button link type="primary" @click="openDialog('edit',scope.row,null)">编辑</el-button>
          <el-button link type="danger" v-if="scope.row.children && scope.row.children.length == 0" @click="handleDelete(scope.row)">删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    <pagination
        v-show="total > 0"
        :total="total"
        v-model:page="queryParams.pageNum"
        v-model:limit="queryParams.pageSize"
        @pagination="getList"
    />
    <edit-dialog ref="dialogRef" @getList=getList></edit-dialog>
    <el-dialog
        v-model="data.copyVisible"
        width="350px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <div style="display: flex;flex-direction: column;align-items: center;justify-content: center" v-loading="copyLoading">
        <span style="font-size: 20px;font-weight: 600;margin-bottom: 8px">选择企业</span>
        <el-select
            v-model="data.chooseCompanyId"
            filterable
            remote
            reserve-keyword
            remote-show-suffix
            :remote-method="getCompanyList"
            style="width: 240px"
        >
          <el-option
              v-for="item in data.companyList"
              :key="item.id"
              :label="item.name"
              :value="item.id"
          />
        </el-select>
      </div>
      <div class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmitCopy" size="default" v-preReClick>确认</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, onUnmounted, reactive, ref, toRefs} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import editDialog from './components/editDialog.vue'
import useUserStore from "@/store/modules/user";
import {delCatalogue, getCatalogue} from "@/api/qualityManage/catalog";
import {getCompany} from "@/api/onlineEducation/company";
import {copeCatalogue} from "@/api/selfProblems/productFile";
const userStore = useUserStore()
const { proxy } = getCurrentInstance();
const loading = ref(false);
const loadingCompany = ref(false)
const dialogRef = ref();
const copyDialog = ref()
const copyLoading = ref(false)
const data = reactive({
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    companyId: null,
  },
  total: 0,
  dataList: [],
  companyList: [],
  industryList: [],
  isAdmin: false,
  copyVisible: false,
  chooseCompanyId: null

});

const { queryParams, total, dataList,companyList,industryList, isAdmin } = toRefs(data);
const userInfo = ref()
onMounted(async ()=>{
  if(userStore.roles.includes('admin')){
    data.isAdmin = true
    data.queryParams.companyId = null
  }else{
    data.isAdmin = false
    data.queryParams.companyId = userStore.companyId
  }

  if(data.isAdmin){
    await getCompanyList()
    data.queryParams.companyId = data.companyList[0].id
    data.queryParams.companyName = data.companyList[0].name
  }
  await getList()
})

onUnmounted(()=>{

})

const getList = async () => {
  loading.value = true
  const param = {
    companyId:data.queryParams.companyId,
    type: 3,
  }
  const res = await getCatalogue(param);
  if(res.code === 200){
    data.dataList = res.data.data
  }else{
    ElMessage.warning(res.message)
  }
  loading.value = false
}

const openDialog = (type, value,flag) => {

  dialogRef.value.openDialog(type, value, data.queryParams.companyId, data.isAdmin,flag);
}
const openCopeDialog = () => {
  data.copyVisible = true
}
const handleClose = () => {
  data.chooseCompanyId = null
  data.copyVisible = false
}

/** 重置新增的表单以及其他数据  */
const reset= async()=> {
  data.queryParams = {
    pageNum: 1,
    pageSize: 10,
    companyId: null,
  }
  await getCompanyList()
  await getList()
}
const handleDelete = (val) => {
  ElMessageBox.confirm(
      '确定删除此条数据？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then( async() => {
        const res = await delCatalogue(val.id)
        if(res.code == 200){
          ElMessage.success('数据删除成功')
          await getList()
        }else{
          ElMessage.warning(res.message)
        }
      })
}
const selectValue = async (val) => {
  data.companyList.forEach(item => {
    if(item.name === val){
      data.queryParams.companyId = item.id
    }
  })
  await getList()
}
const getCompanyList = async (val)=>{
  if(val){
    loadingCompany.value = true;
    const queryParams = {
      name: val
    }
    const res = await getCompany(queryParams)
    if (res.code == 200) {
      loadingCompany.value = false;
      data.companyList = res.data.list

    } else {
      ElMessage.warning(res.message)
    }
  }else {
    loadingCompany.value = true;
    const queryParams = {
      pageSize: 100,
      pageNum: 1,
    }
    const res = await getCompany(queryParams)
    if (res.code == 200) {
      loadingCompany.value = false;
      data.companyList = res.data.list

    } else {
      ElMessage.warning(res.message)
    }
  }
}
const onSubmitCopy = async () => {
  if(!data.chooseCompanyId){
    ElMessage.warning('请先选择企业')
    return
  }
  let copyData = []
  const p= {
    companyId:data.chooseCompanyId,
    type: 3,
  }
  const r = await getCatalogue(p);
  if(r.code === 200){
    if(r.data.data.length >0){
      copyData = r.data.data
    }else {
      ElMessage.warning('当前选择企业下暂无目录，请重新选择！')
      return
    }
  }else{
    ElMessage.warning(r.message)
  }
  if(data.dataList && data.dataList.length >0){
    ElMessageBox.confirm(
      '当前企业已有数据，是否覆盖原有数据？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then( async() => {
        await copyDataList(copyData)
      }).catch(err => {
        console.log('取消')
    })
  }else {
    await copyDataList(copyData)
  }
}
const copyDataList = async (copyData) => {
  copyData.forEach(item => {
    item.companyId = data.queryParams.companyId
  })
  copyLoading.value = true
  const res = await copeCatalogue(copyData);
  if(res.code === 200){
    ElMessage.success('复制成功')
    copyLoading.value = false
    data.copyVisible = false
    data.chooseCompanyId = null
    await getList()
  }else{
    ElMessage.warning(res.message)
  }
}
</script>

<style scoped lang="scss">
.dialog-footer{
  margin-top: 20px;
  text-align: right;
  margin-bottom: -5px;
}
</style>
